@@ -56,6 +56,7 @@ BEGIN {
 use Carp qw(croak);
 use Const::Fast;
 use Date::Parse qw(str2time);
+use Debian::Debhelper::Dh_Lib qw(doit);
 use IPC::Run3;
 use List::SomeUtils qw(uniq any first_value);
 use Path::Tiny;
@@ -638,8 +639,7 @@ sub build_recipe {
     die encode_utf8('No Haskell compiler.')
       unless length $compiler;
 
-    my $output
-      = run($ENV{DEB_SETUP_BIN_NAME},'build', "--builddir=dist-$compiler");
+    doit($ENV{DEB_SETUP_BIN_NAME}, 'build', "--builddir=dist-$compiler");
 
     return;
 }
@@ -674,7 +674,7 @@ sub check_recipe {
     die encode_utf8('No Haskell compiler.')
       unless length $compiler;
 
-    my $output = run($ENV{DEB_SETUP_BIN_NAME},
+    doit($ENV{DEB_SETUP_BIN_NAME},
         'test', "--builddir=dist-$compiler", '--show-details=direct');
 
     return;
